/**
 * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
CKEDITOR.plugins.setLang( 'widget', 'fa', {
	'move': 'کلیک و کشیدن برای جابجایی',
	'label': 'ابزارک %1'
} );
